@@ -79,15 +79,21 @@ class TeslaCar:
         """Return if data from VEHICLE_DATA endpoint is available."""
         # self._vehicle_data gets updated with some data from VEHICLE_LIST endpoint
         # Only return True if data specifically from VEHICLE_DATA endpoint is available
-        if self._vehicle_data.get("vehicle_config", {}):
+        # vehicle_state is only from the VEHICLE_DATA endpoint
+        if self._vehicle_data.get("vehicle_state", {}):
             return True
         return None
 
     @property
     def battery_level(self) -> float:
-        """Return car battery level."""
+        """Return car battery level (SOC). This is not affected by temperature."""
         return self._vehicle_data.get("charge_state", {}).get("battery_level")
 
+    @property
+    def usable_battery_level(self) -> float:
+        """Return car usable battery level (uSOE). This is the value used in the app and car."""
+        return self._vehicle_data.get("charge_state", {}).get("usable_battery_level")
+
     @property
     def battery_range(self) -> float:
         """Return car battery range."""
@@ -256,6 +262,26 @@ class TeslaCar:
         """Return fast charger type."""
         return self._vehicle_data.get("charge_state", {}).get("fast_charger_type")
 
+    @property
+    def door_df(self) -> int:
+        """Return driver front door status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("df")
+
+    @property
+    def door_dr(self) -> int:
+        """Return driver rear door status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("dr")
+
+    @property
+    def door_pf(self) -> int:
+        """Return passenger front door status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("pf")
+
+    @property
+    def door_pr(self) -> int:
+        """Return passenger rear door status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("pr")
+
     @property
     def gui_distance_units(self) -> str:
         """Return gui distance units."""
@@ -420,7 +446,7 @@ class TeslaCar:
     @property
     def powered_lift_gate(self) -> bool:
         """Return True if car has power lift gate."""
-        return self._vehicle_data.get("vehicle_config", {}).get("plg")
+        return self._car.get("vehicle_config", {}).get("plg")
 
     @property
     def rear_seat_heaters(self) -> int:
@@ -430,7 +456,7 @@ class TeslaCar:
             int: 0 (no rear heated seats), int: ? (rear heated seats)
 
         """
-        return self._vehicle_data.get("vehicle_config", {}).get("rear_seat_heaters")
+        return self._car.get("vehicle_config", {}).get("rear_seat_heaters")
 
     @property
     def sentry_mode(self) -> bool:
@@ -460,7 +486,27 @@ class TeslaCar:
     @property
     def steering_wheel_heater(self) -> bool:
         """Return steering wheel heater option."""
-        return self._vehicle_data.get("climate_state", {}).get("steering_wheel_heater")
+        return self._vehicle_data.get("climate_state", {}).get("steering_wheel_heater") is not None
+
+    @property
+    def tpms_pressure_fl(self) -> float:
+        """Return tire pressure sensor for front left tire."""
+        return self._vehicle_data.get("vehicle_state", {}).get("tpms_pressure_fl")
+
+    @property
+    def tpms_pressure_fr(self) -> float:
+        """Return tire pressure sensor for front right tire."""
+        return self._vehicle_data.get("vehicle_state", {}).get("tpms_pressure_fr")
+
+    @property
+    def tpms_pressure_rl(self) -> float:
+        """Return tire pressure sensor for rear left tire."""
+        return self._vehicle_data.get("vehicle_state", {}).get("tpms_pressure_rl")
+
+    @property
+    def tpms_pressure_rr(self) -> float:
+        """Return tire pressure sensor for rear right tire."""
+        return self._vehicle_data.get("vehicle_state", {}).get("tpms_pressure_rr")
 
     @property
     def third_row_seats(self) -> str:
@@ -470,13 +516,45 @@ class TeslaCar:
             str: None
 
         """
-        return self._vehicle_data.get("vehicle_config", {}).get("third_row_seats")
+        return self._car.get("vehicle_config", {}).get("third_row_seats")
 
     @property
     def time_to_full_charge(self) -> float:
         """Return time to full charge."""
         return self._vehicle_data.get("charge_state", {}).get("time_to_full_charge")
 
+    @property
+    def window_fd(self) -> int:
+        """Return front driver window status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("fd_window")
+
+    @property
+    def window_fp(self) -> int:
+        """Return front passenger window status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("fp_window")
+
+    @property
+    def window_rd(self) -> int:
+        """Return rear driver window status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("rd_window")
+
+    @property
+    def window_rp(self) -> int:
+        """Return rear passenger window status."""
+        return self._vehicle_data.get("vehicle_state", {}).get("rp_window")
+
+    @property
+    def is_window_closed(self) -> bool:
+        """Return all car windows are close."""
+        if (
+            self._vehicle_data.get("vehicle_state", {}).get("fd_window")
+            or self._vehicle_data.get("vehicle_state", {}).get("fp_window")
+            or self._vehicle_data.get("vehicle_state", {}).get("rd_window")
+            or self._vehicle_data.get("vehicle_state", {}).get("rp_window")
+        ):
+            return False
+        return True
+
     async def _send_command(
         self, name: str, *, path_vars: dict, wake_if_asleep: bool = False, **kwargs
     ) -> dict:
@@ -502,6 +580,16 @@ class TeslaCar:
 
         return lat, long
 
+    def update_car_info(self, car: dict) -> None:
+        """Update the car info dict from the vehicle_list api."""
+        if not car:
+            _LOGGER.debug("Attempted to update car id %d with empty car info", self.id)
+            return
+        if car["vin"] != self.vin:
+            _LOGGER.error("Failed updating car info: new VIN (%s) doesn't match existing vin (%s)", car["vin"][-5:], self.vin[-5:])
+            return
+        self._car.update(car)
+
     async def change_charge_limit(self, value: float) -> None:
         """Send command to change charge limit."""
         data = await self._send_command(
@@ -890,3 +978,41 @@ class TeslaCar:
         if data and data["response"]["result"] is True:
             params = {"locked": False}
             self._vehicle_data["vehicle_state"].update(params)
+
+    async def vent_windows(self) -> None:
+        """Vent Windows."""
+        data = await self._send_command(
+            "WINDOW_CONTROL",
+            path_vars={"vehicle_id": self.id},
+            command="vent",
+            lat=0,
+            long=0,
+            wake_if_asleep=True,
+        )
+        if data and data["response"]["result"] is True:
+            params = {
+                "fd_window": 1,
+                "fp_window": 1,
+                "rd_window": 1,
+                "rp_window": 1,
+            }
+            self._vehicle_data["vehicle_state"].update(params)
+
+    async def close_windows(self) -> None:
+        """Close Windows."""
+        data = await self._send_command(
+            "WINDOW_CONTROL",
+            path_vars={"vehicle_id": self.id},
+            command="close",
+            lat=self.latitude,
+            long=self.longitude,
+            wake_if_asleep=True,
+        )
+        if data and data["response"]["result"] is True:
+            params = {
+                "fd_window": 0,
+                "fp_window": 0,
+                "rd_window": 0,
+                "rp_window": 0,
+            }
+            self._vehicle_data["vehicle_state"].update(params)
